import request from '@/utils/request'

// 查询上岗记录列表
export function listPostRecord(query) {
  return request({
    url: '/attendance/postRecord/list',
    method: 'get',
    params: query
  })
}

// 查询上岗记录详细
export function getPostRecord(id) {
  return request({
    url: '/attendance/postRecord/' + id,
    method: 'get'
  })
}

// 新增上岗记录
export function addPostRecord(data) {
  return request({
    url: '/attendance/postRecord',
    method: 'post',
    data: data
  })
}

// 修改上岗记录
export function updatePostRecord(data) {
  return request({
    url: '/attendance/postRecord',
    method: 'put',
    data: data
  })
}

// 删除上岗记录
export function delPostRecord(id) {
  return request({
    url: '/attendance/postRecord/' + id,
    method: 'delete'
  })
}

// 查询位置信息
export function positionList(data) {
  return request({
    url: '/attendance/postRecord/positionList',
    method: 'post',
    data: data
  })
}

// 查询班组信息
export function teamList(data) {
  return request({
    url: '/system/dept/teamList',
    method: 'post',
    data: data
  })
}


//查询用户列表
export function selectUserListByCondition(data) {
  return request({
    url: '/system/user/selectUserListByCondition',
    method: 'post',
    data: data
  })
}
