<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch">
      <el-form-item label="用户名称" prop="userName">
        <el-input v-model="queryParams.userName" placeholder="请输入用户名称" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="班组名称" prop="attendanceTeamName">
        <el-input v-model="queryParams.attendanceTeamName" placeholder="请输入班组名称" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="主管名称" prop="attendanceDepartmentName">
        <el-input v-model="queryParams.attendanceDepartmentName" placeholder="请输入主管名称" clearable
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="大队名称" prop="attendanceBrigadeName">
        <el-input v-model="queryParams.attendanceBrigadeName" placeholder="请输入大队名称" clearable
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="考勤日期" prop="attendanceDate">
        <el-date-picker clearable v-model="dateRange" value-format="YYYY-MM-DD" type="daterange" range-separator="-"
          start-placeholder="开始日期" end-placeholder="结束日期">
        </el-date-picker>
      </el-form-item>
      <el-form-item label="航站楼名称" prop="terminlName">
        <el-input v-model="queryParams.terminlName" placeholder="请输入航站楼名称" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="区域名称" prop="regionalName">
        <el-input v-model="queryParams.regionalName" placeholder="请输入区域名称" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="通道名称" prop="channelName">
        <el-input v-model="queryParams.channelName" placeholder="请输入通道名称" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <!-- <el-form-item label="岗位名称" prop="positionName">
        <el-input
          v-model="queryParams.positionName"
          placeholder="请输入岗位名称"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item> -->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="handleAdd"
          v-hasPermi="['attendance:postRecord:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['attendance:postRecord:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="Download" @click="handleExport"
          v-hasPermi="['attendance:postRecord:export']">导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="info" plain icon="Upload" @click="handleImport"
          v-hasPermi="['attendance:postRecord:import']">导入</el-button>
      </el-col>
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="postRecordList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="用户姓名" align="center" prop="userName" width="80" />
      <el-table-column label="班组名称" align="center" prop="attendanceTeamName" width="80" />
      <el-table-column label="主管名称" align="center" prop="attendanceDepartmentName" width="80" />
      <el-table-column label="大队名称" align="center" prop="attendanceBrigadeName" width="80" />
      <el-table-column label="考勤日期" align="center" prop="attendanceDate" width="100" />
      <el-table-column label="上岗时间" align="center" prop="checkInTime" width="155" />
      <el-table-column label="离岗时间" align="center" prop="checkOutTime" width="155">
        <template #default="scope">
          {{ scope.row.checkOutTime == '2000-01-01 00:00:00' ? '' : scope.row.checkOutTime }}
        </template>
      </el-table-column>
      <el-table-column label="工作时长(分钟)" align="center" prop="workDuration" width="115" />
      <el-table-column label="航站楼名称" align="center" prop="terminlName" width="110" />
      <el-table-column label="区域名称" align="center" prop="regionalName" width="110" />
      <el-table-column label="通道名称" align="center" prop="channelName" width="110" />

      <!-- <el-table-column label="岗位名称" align="center" prop="positionName" width="110" /> -->
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="140">
        <template #default="scope">
          <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['attendance:postRecord:edit']">修改</el-button>
          <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)"
            v-hasPermi="['attendance:postRecord:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum"
      v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改上岗记录对话框 -->
    <el-dialog :title="title" v-model="open" width="400px" append-to-body>
      <el-form ref="postRecordRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="班组" prop="attendanceTeamId" clearable>
          <el-select v-model="form.attendanceTeamId" filterable placeholder="请选择班组" style="width: 288px"
            @change="handleTeamChange">
            <el-option v-for="item in teamOptions" :key="item.value" :label="item.label" :value="item.value" />
          </el-select>
        </el-form-item>
        <el-form-item label="用户" prop="userIdList">
          <template v-if="disabledUserSelect">
            <el-input v-model="form.userName" :disabled="disabledUserSelect" />
          </template>
          <template v-else>
            <UserSelect ref="userSelect" v-model="form.userIdList" :disabled="disabledUserSelect" width="288px"
              :multiple="true" />
          </template>
        </el-form-item>
        <el-form-item label="上岗时间" prop="checkInTime">
          <el-date-picker clearable style="width:288px" v-model="form.checkInTime" type="datetime"
            format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择上岗时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="离岗时间" prop="checkOutTime">
          <el-date-picker clearable style="width:288px" v-model="form.checkOutTime" type="datetime"
            format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择离岗时间">
          </el-date-picker>
        </el-form-item>

        <el-form-item label="通道" prop="terminlCode" clearable>
          <el-cascader v-model="form.positionValue" :options="positonOptions" @change="handlePositionChange"
            placeholder="请选择航站楼、区域、通道" style="width: 288px" />
        </el-form-item>
        <!-- <el-form-item label="岗位" prop="positionCode">
          <el-select v-model="form.positionCode" placeholder="请选择岗位" clearable style="width: 288px">
            <el-option
              v-for="dict in item_check_method"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            />
          </el-select>
        </el-form-item> -->
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>


    <!-- 上岗记录导入对话框 -->
    <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
      <el-upload ref="uploadRef" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
        :action="upload.url + '?updateSupport=' + upload.updateSupport" :disabled="upload.isUploading"
        :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess" :auto-upload="false" drag>
        <el-icon class="el-icon--upload"><upload-filled /></el-icon>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <template #tip>
          <div class="el-upload__tip text-center">
            <!-- <div class="el-upload__tip">
              <el-checkbox v-model="upload.updateSupport" />是否更新已经存在的用户数据
            </div> -->
            <span>仅允许导入xls、xlsx格式文件。</span>
            <el-link type="primary" :underline="false" style="font-size: 12px; vertical-align: baseline"
              @click="importTemplate">下载模板</el-link>
          </div>
        </template>
      </el-upload>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitFileForm">确 定</el-button>
          <el-button @click="upload.open = false">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="PostRecord">
import { listPostRecord, getPostRecord, delPostRecord, addPostRecord, updatePostRecord, positionList, teamList, selectUserListByCondition } from "@/api/attendance/postRecord"

import UserSelect from "@/components/UserSelect"

const { proxy } = getCurrentInstance()

const { item_check_method } = proxy.useDict('item_check_method')

const postRecordList = ref([])
const open = ref(false)
const loading = ref(true)
const showSearch = ref(true)
const ids = ref([])
const single = ref(true)
const multiple = ref(true)
const total = ref(0)
const title = ref("")
const dateRange = ref([])
// 控制 UserSelect 组件是否可编辑
const disabledUserSelect = ref(false)
const positonOptions = ref([])

const teamOptions = ref([])

import { getToken } from "@/utils/auth"

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    tenantId: null,
    revision: null,
    userIdList: null,
    channelCode: null,
    shiftCode: null,
    checkInTime: null,
    checkOutTime: null,
    workDuration: null,
    status: null,
    attendanceDate: null,
    attendanceTeamId: null,
    overDuration: null,
    attendanceTeamName: null,
    attendanceDepartmentId: null,
    attendanceDepartmentName: null,
    attendanceStationId: null,
    attendanceStationName: null,
    channelName: null,
    regionalCode: null,
    regionalName: null,
    terminlCode: null,
    terminlName: null,
    userName: null,
    shiftName: null,
    remark: null,
    statusDesc: null
  },
  rules: {
    userIdList: [
      { required: !disabledUserSelect, message: "用户ID不能为空", trigger: "blur" }
    ],
    channelCode: [
      { required: true, message: "通道编码不能为空", trigger: "blur" }
    ],
    // positionCode: [
    //   { required: true, message: "岗位编码不能为空", trigger: "blur" }
    // ],
    checkInTime: [
      { required: true, message: "上岗时间不能为空", trigger: "blur" }
    ],
    checkOutTime: [
      { required: true, message: "离岗时间不能为空", trigger: "blur" }
    ],
    workDuration: [
      { required: true, message: "工作时长(分钟)不能为空", trigger: "blur" }
    ],
    status: [
      { required: true, message: "考勤状态不能为空", trigger: "change" }
    ],
    attendanceDate: [
      { required: true, message: "考勤日期不能为空", trigger: "blur" }
    ],
    overDuration: [
      { required: true, message: "加班时长(分钟)不能为空", trigger: "blur" }
    ],
    attendanceTeamName: [
      { required: true, message: "考勤班组名称不能为空", trigger: "blur" }
    ],
    attendanceDepartmentId: [
      { required: true, message: "考勤主管ID不能为空", trigger: "blur" }
    ],
    attendanceDepartmentName: [
      { required: true, message: "考勤主管名称不能为空", trigger: "blur" }
    ],
    attendanceStationId: [
      { required: true, message: "考勤机构站ID不能为空", trigger: "blur" }
    ],
    attendanceStationName: [
      { required: true, message: "考勤机构站名称不能为空", trigger: "blur" }
    ],
    channelName: [
      { required: true, message: "通道名称不能为空", trigger: "blur" }
    ],
    regionalCode: [
      { required: true, message: "区域编码不能为空", trigger: "blur" }
    ],
    regionalName: [
      { required: true, message: "区域名称不能为空", trigger: "blur" }
    ],
    terminlCode: [
      { required: true, message: "航站楼编码不能为空", trigger: "blur" }
    ],
    terminlName: [
      { required: true, message: "航站楼名称不能为空", trigger: "blur" }
    ],
    userName: [
      { required: true, message: "用户名称不能为空", trigger: "blur" }
    ],
    shiftName: [
      { required: true, message: "班次名称不能为空", trigger: "blur" }
    ],
    statusDesc: [
      { required: true, message: "考勤状态名称不能为空", trigger: "blur" }
    ]
  }
})

const upload = reactive({
  // 是否显示弹出层
  open: false,
  // 弹出层标题
  title: "",
  // 是否禁用上传
  isUploading: false,
  // 是否更新已经存在的用户数据
  updateSupport: 0,
  // 设置上传的请求头部
  headers: { Authorization: "Bearer " + getToken() },
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + "/attendance/postRecord/importData"
})

const { queryParams, form, rules } = toRefs(data)


const handleTeamChange = async (newTeamId) => {

  if (newTeamId) {
    // 当班组ID变化时，获取该班组的成员
    try {
      const response = await selectUserListByCondition({
        deptId: newTeamId, roleKeyList: [
          "banzuzhang","SecurityCheck"
        ],
      })
      // 获取团队成员的用户ID列表
      const teamUserIds = response.data.map(item => item.userId)
      // 将团队成员的用户ID赋值给form.userId
      form.value.userIdList = teamUserIds
    } catch (error) {
      console.error('获取班组成员失败:', error)
    }
  }
}


/** 查询上岗记录列表 */
function getList() {
  loading.value = true
  let params = {
    ...queryParams.value,
    beginTime: dateRange.value[0],
    endTime: dateRange.value[1],
    // ...proxy.addDateRange(queryParams.value, dateRange.value)
  }
  listPostRecord(params).then(response => {
    postRecordList.value = response.rows
    total.value = response.total
    loading.value = false
  })
}

// 获取级联数据
const fetchPositionData = async () => {
  try {
    const response = await positionList({})
    positonOptions.value = response.data
  } catch (error) {
    console.error('获取通道级联数据失败:', error)
  }
}
const fetchTeamData = async () => {
  try {
    const response = await teamList({})
    const d = response.data
    for (const key in d) {
      if (d.hasOwnProperty(key)) {
        const option = { "value": Number(key), "label": d[key] }
        teamOptions.value.push(option)
      }
    }
  } catch (error) {
    console.error('获取班组数据失败:', error)
  }
}

// 级联选择变化时的处理函数
const handlePositionChange = (value) => {
  if (value.length === 3) {
    form.value.terminlCode = value[0]
    form.value.regionalCode = value[1]
    form.value.channelCode = value[2]
  }
}

// 取消按钮
function cancel() {
  open.value = false
  reset()
}

// 表单重置
function reset() {
  form.value = {
    tenantId: null,
    revision: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null,
    userIdList: [], // 改为数组默认值
    channelCode: null,
    shiftCode: null,
    checkInTime: null,
    checkOutTime: null,
    workDuration: null,
    status: null,
    attendanceDate: null,
    attendanceTeamId: null,
    overDuration: null,
    id: null,
    attendanceTeamName: null,
    attendanceDepartmentId: null,
    attendanceDepartmentName: null,
    attendanceStationId: null,
    attendanceStationName: null,
    channelName: null,
    regionalCode: null,
    regionalName: null,
    terminlCode: null,
    terminlName: null,
    userName: null,
    shiftName: null,
    remark: null,
    statusDesc: null
  }
  proxy.resetForm("postRecordRef")
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1
  getList()
}

/** 重置按钮操作 */
function resetQuery() {
  dateRange.value = []
  proxy.resetForm("queryRef")
  handleQuery()
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id)
  single.value = selection.length != 1
  multiple.value = !selection.length
}

/** 新增按钮操作 */
function handleAdd() {
  reset()
  open.value = true
  title.value = "添加上岗记录"
  // 新增时允许编辑
  disabledUserSelect.value = false
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset()
  const _id = row.id || ids.value
  getPostRecord(_id).then(response => {
    form.value = response.data
    // 根据实际数据结构设置默认值
    form.value.positionValue = [
      form.value.terminlCode,
      form.value.regionalCode,
      form.value.channelCode
    ]
    open.value = true
    title.value = "修改上岗记录"
    // 修改时禁止编辑
    disabledUserSelect.value = true
  })
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["postRecordRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updatePostRecord(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功")
          open.value = false
          getList()
        })
      } else {
        addPostRecord(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功")
          open.value = false
          getList()
        })
      }
    }
  })
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value
  proxy.$modal.confirm('是否确认删除数据项？').then(function () {
    return delPostRecord(_ids)
  }).then(() => {
    getList()
    proxy.$modal.msgSuccess("删除成功")
  }).catch(() => { })
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('attendance/postRecord/export', {
    ...queryParams.value
  }, `postRecord_${new Date().getTime()}.xlsx`)
}

onMounted(() => {
  fetchPositionData()
  fetchTeamData()
  getList()
})


/** 导入按钮操作 */
function handleImport() {
  upload.title = "上岗记录导入"
  upload.open = true
}

/** 下载模板操作 */
function importTemplate() {
  proxy.download("attendance/postRecord/importTemplate", {
  }, `record_template_${new Date().getTime()}.xlsx`)
}

/**文件上传中处理 */
const handleFileUploadProgress = (event, file, fileList) => {
  upload.isUploading = true
}

/** 文件上传成功处理 */
const handleFileSuccess = (response, file, fileList) => {
  upload.open = false
  upload.isUploading = false
  proxy.$refs["uploadRef"].handleRemove(file)
  proxy.$alert("<div style='overflow: auto;overflow-x: hidden;max-height: 70vh;padding: 10px 20px 0;'>" + response.msg + "</div>", "导入结果", { dangerouslyUseHTMLString: true })
  getList()
}

/** 提交上传文件 */
function submitFileForm() {
  proxy.$refs["uploadRef"].submit()
}
</script>
